@@ -13,7 +13,9 @@
  */
 #pragma once
 
-#include "folder.h"
+#include "gui/owncloudguilib.h"
+
+#include "gui/folder.h"
 
 #include "csync/csync.h"
 #include "libsync/syncfileitem.h"
@@ -22,18 +24,19 @@
 
 namespace OCC {
 
-class ProtocolItem
+class OWNCLOUDGUI_EXPORT ProtocolItem
 {
     Q_GADGET
 public:
     ProtocolItem() = default;
     explicit ProtocolItem(Folder *folder, const SyncFileItemPtr &item);
-    explicit ProtocolItem(const QString &folder, const SyncFileItemPtr &item);
-
     QString path() const;
 
     Folder *folder() const;
 
+    /**
+     * UTC Time
+     */
     QDateTime timestamp() const;
 
     qint64 size() const;
@@ -51,8 +54,8 @@ private:
     Folder *_folder;
     QDateTime _timestamp;
     qint64 _size;
-    SyncFileItem::Status _status BITFIELD(4);
-    SyncFileItem::Direction _direction BITFIELD(3);
+    SyncFileItem::Status _status;
+    SyncFileItem::Direction _direction;
 
     QString _message;
     bool _sizeIsRelevant;
